@@ -234,19 +234,6 @@ cal_backend_kolab_notify_opened (ECalBackendKolab *self,
 	return TRUE;
 }
 
-static void
-cal_backend_kolab_notify_removed (ECalBackendKolab *self)
-{
-	ECalBackend *cbackend = NULL;
-
-	g_assert (E_IS_CAL_BACKEND_KOLAB (self));
-
-	cbackend = E_CAL_BACKEND (self);
-
-	e_cal_backend_notify_readonly (cbackend, TRUE);
-	e_cal_backend_notify_online (cbackend, FALSE);
-}
-
 /*----------------------------------------------------------------------------*/
 /* class functions */
 
@@ -413,48 +400,6 @@ cal_backend_kolab_open (ECalBackendSync *backend,
 	}
 }
 
-static void
-cal_backend_kolab_remove (ECalBackendSync *backend,
-                          EDataCal *cal,
-                          GCancellable *cancellable,
-                          GError **error)
-{
-	ECalBackendKolab *self = NULL;
-	ECalBackendKolabPrivate *priv = NULL;
-	GError *tmp_err = NULL;
-	gboolean ok = FALSE;
-
-	g_return_if_fail (error == NULL || *error == NULL);
-	e_return_data_cal_error_if_fail (E_IS_CAL_BACKEND_KOLAB (backend), InvalidArg);
-	/* cancellable may be NULL */
-	e_return_data_cal_error_if_fail (E_IS_DATA_CAL (cal), InvalidArg);
-
-	self = E_CAL_BACKEND_KOLAB (backend);
-	priv = E_CAL_BACKEND_KOLAB_PRIVATE (self);
-
-	if (priv->cal_koma != NULL) {
-		ok = kolab_mail_access_shutdown (priv->cal_koma,
-		                                 cancellable,
-		                                 &tmp_err);
-		if (ok) {
-			g_object_unref (priv->cal_koma);
-			priv->cal_koma = NULL;
-		} else {
-			g_propagate_error (error, tmp_err);
-		}
-	}
-
-	if (priv->cal_cache != NULL) {
-		(void) e_file_cache_remove (E_FILE_CACHE (priv->cal_cache));
-		g_object_unref (priv->cal_cache);
-		priv->cal_cache = NULL;
-	}
-
-	if (ok) {
-		cal_backend_kolab_notify_removed (self);
-	}
-}
-
 static void
 cal_backend_kolab_refresh (ECalBackendSync *backend,
                            EDataCal *cal,
@@ -1216,10 +1161,10 @@ cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 			id = g_new0 (ECalComponentId, 1);
 			id->uid = g_strdup (uid);
 			id->rid = g_strdup (rid);
-			e_cal_backend_notify_object_removed (E_CAL_BACKEND (backend),
-			                                     id,
-			                                     NULL,
-			                                     NULL);
+			e_cal_backend_notify_component_removed (E_CAL_BACKEND (backend),
+			                                        id,
+			                                        NULL,
+			                                        NULL);
 			g_free (id);
 			break;
 		default:
@@ -1710,6 +1655,7 @@ cal_backend_kolab_start_view (ECalBackend *backend,
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
+	ECalBackendSExp *sexp;
 	GList *uid_list = NULL;
 	GList *it = NULL;
 	GSList *iCal_objects = NULL;
@@ -1735,7 +1681,8 @@ cal_backend_kolab_start_view (ECalBackend *backend,
 		goto exit;
 	}
 
-	query = e_data_cal_view_get_text (view);
+	sexp = e_data_cal_view_get_sexp (view);
+	query = e_cal_backend_sexp_text (sexp);
 	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	/* try to switch into online mode. if that fails,
@@ -1980,7 +1927,6 @@ e_cal_backend_kolab_class_init (ECalBackendKolabClass *klass)
 
 	/* Sync backend class functions */
 	sync_class->open_sync = cal_backend_kolab_open;
-	sync_class->remove_sync = cal_backend_kolab_remove;
 	sync_class->refresh_sync = cal_backend_kolab_refresh;
 	sync_class->get_backend_property_sync = cal_backend_kolab_get_backend_property;
 	sync_class->get_object_sync = cal_backend_kolab_get_object;
