@@ -34,8 +34,8 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
+#include <e-util/e-util.h>
 #include <shell/e-shell-view.h>
-#include <misc/e-alert-bar.h>
 
 #include <libekolab/kolab-data-folder-metadata.h>
 
